import axios from 'axios'
//设置全局的请求次数，请求的间隙
axios.defaults.retry = 3;
axios.defaults.retryDelay = 2000;

//创建axios的一个实例
var instance = axios.create({
	baseURL: '',
	timeout: 6000
})
/**
 * 使用es6的export default导出了一个函数，导出的函数代替axios去帮我们请求数据，
 * 函数的参数及返回值如下：
 * @param {String} url     请求的url:
 * @param {String} method  请求的方法：get、post、delete、put
 * @param {Object} data    请求的参数
 * @returns {Promise}     返回一个promise对象，其实就相当于axios请求数据的返回值
 */
export default function(url, method, data = null, callback) {
	method = method.toLowerCase();
	if (method == 'post') {
		return new Promise((resolve, reject) => {
			instance.post(url, data).then(res => {
				resolve(res)
				callback(res)
			}).catch(err => {
				reject(err)
			})

		})
	} else if (method == 'get') {
		return new Promise((resolve, reject) => {
			instance.get(url, {
				params: data
			}).then(res => {
				resolve(res)
				callback(res)
			}).catch(err => {
				reject(err)
			})
		})
	} else if (method == 'delete') {
		return new Promise((resolve, reject) => {
			instance.delete(url, {
				params: data
			}).then(res => {
				resolve(res)
				callback(res)
			}).catch(err => {
				reject(err)
			})
		})
	} else if (method == 'put') {
		return new Promise((resolve, reject) => {
			instance.put(url, data).then(res => {
				resolve(res)
				callback(res)
			}).catch(err => {
				reject(err)
			})
		})
	} else if (method == 'patch') {
		return new Promise((resolve, reject) => {
			instance.patch(url, data).then(res => {
				resolve(res)
				callback(res)
			}).catch(err => {
				reject(err)
			})
		})
	} else {
		console.error('未知的method' + method)
	}
}
